@@ -32,8 +32,8 @@ class CreateBenchmarkTaskRequest(RoaRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_body(self): # string
+	def get_body(self): # String
 		return self.get_body_params().get('body')
 
-	def set_body(self, body):  # string
+	def set_body(self, body):  # String
 		self.add_body_params('body', body)
