@@ -26,14 +26,14 @@ class CreateResourceRequest(RoaRequest):
 		RoaRequest.__init__(self, 'eas', '2021-07-01', 'CreateResource','eas')
 		self.set_uri_pattern('/api/v2/resources')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_body(self):
+	def get_body(self): # String
 		return self.get_body_params().get('body')
 
-	def set_body(self,body):
-		self.add_body_params('body', body)
\ No newline at end of file
+	def set_body(self, body):  # String
+		self.add_body_params('body', body)
