@@ -32,3 +32,23 @@ class ListBenchmarkTaskRequest(RoaRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Filter(self): # String
+		return self.get_query_params().get('Filter')
+
+	def set_Filter(self, Filter):  # String
+		self.add_query_param('Filter', Filter)
+	def get_PageSize(self): # String
+		return self.get_query_params().get('PageSize')
+
+	def set_PageSize(self, PageSize):  # String
+		self.add_query_param('PageSize', PageSize)
+	def get_ServiceName(self): # String
+		return self.get_query_params().get('ServiceName')
+
+	def set_ServiceName(self, ServiceName):  # String
+		self.add_query_param('ServiceName', ServiceName)
+	def get_PageNumber(self): # String
+		return self.get_query_params().get('PageNumber')
+
+	def set_PageNumber(self, PageNumber):  # String
+		self.add_query_param('PageNumber', PageNumber)
