@@ -32,15 +32,15 @@ class UpdateResourceRequest(RoaRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_ResourceId(self): # string
+	def get_ResourceId(self): # String
 		return self.get_path_params().get('ResourceId')
 
-	def set_ResourceId(self, ResourceId):  # string
+	def set_ResourceId(self, ResourceId):  # String
 		self.add_path_param('ResourceId', ResourceId)
-	def get_ClusterId(self): # string
+	def get_ClusterId(self): # String
 		return self.get_path_params().get('ClusterId')
 
-	def set_ClusterId(self, ClusterId):  # string
+	def set_ClusterId(self, ClusterId):  # String
 		self.add_path_param('ClusterId', ClusterId)
 	def get_body(self): # String
 		return self.get_body_params().get('body')
